#! /usr/bin/env bash
# This script records a complete sequence of commands to reproduce this
# package build in the CodeSourcery environment.  It includes commands
# requiring proprietary sources not included in the source package
# and the actual directory names used in the build.  Running this
# script outside the CodeSourcery environment is not supported, but
# it serves to provide documentation of how the open source components
# of this package have been configured.  If these components are
# built outside CodeSourcery, the --with-pkgversion and
# --with-bugurl configuration options that embed CodeSourcery
# trademarks in the resulting binary must be removed; see the
# "CodeSourcery Trademarks" section in the Sourcery G++ Software
# License Agreement.
set -e
inform_fd=2 

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	return "$status"
    fi
}

check_pipe() {
    local -a status=("${PIPESTATUS[@]}")
    local limit=$1
    local ix
    
    if [ -z "$limit" ] ; then
	limit="${#status[@]}"
    fi
    for ((ix=0; ix != $limit ; ix++)); do
	if [ "${status[$ix]}" != "0" ] ; then
	    return "${status[$ix]}"
	fi
    done
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

copy_dir() {
    mkdir -p "$2"
    # Use tar, rather than cp -r, so that symlinks are preserved.
    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe
}

update_dir_clean() {
    mkdir -p "$2"
    # Redirect tar to /dev/null because GNU tar 1.15.1 is chatty on
    # --after-date; this is fixed in GNU tar 1.16.
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	--after-date="$3" \
	. 2> /dev/null) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

clean_environment() {
    local env_var_list
    local var

    # Unset variables taken by bash from the environment in
    # noninteractive shells and affecting bash itself in undesirable
    # ways.  Other variables need only be unexported.
    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    CSL_SCRIPTDIR|HOME|LOGNAME|PWD|SHELL|SHLVL|SSH_*|TERM|USER)
		# These variables are OK to export and may be required
		# by this process or subprocesses.
		;;
	    LD_LIBRARY_PATH|PATH| \
		FLEXLM_NO_CKOUT_INSTALL_LIC|LM_APP_DISABLE_CACHE_READ)
		# PATH and LD_LIBRARY_PATH are set separately after
		# the release config has been read; see setup_path.
		;;
	    *_LICENSE_FILE)
		# If $license_building is not true, then one of two
		# things is true: clean_environment is getting called
		# before we have read the release configuration or
		# clean_environment is getting called after we have
		# read the release configuration and we are not
		# building with license support.  In either case,
		# we need to remove this variable from the
		# environment.
		#
		# If $license_building is true, we need to ensure that
		# we do not remove the *_LICENSE_FILE variable that
		# setup_path has exported.
		if [ "$license_building" ]; then
		    local license_file_envvar
		    license_file_envvar=$(license_print_license_file_envvar)

		    if [ "$var" != "$license_file_envvar" ]; then
			export -n "$var" || true
		    fi
		else
		    export -n "$var" || true
		fi
		;;
	    *)
		# On Cygwin, there are environment variables that cannot be unset, like "!C".
		export -n "$var" || true
		;;
	esac
    done

    # Use the C locale.
    export LANG=C
    export LC_ALL=C

    # Used for local CVS checkouts.
    export CVS_RSH=ssh

    # Ensure the shell running this script is also used for other
    # purposes.
    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/paul/arm/scripts
pushenvvar PATH /usr/local/tools/gcc-3.4.0/bin:/bin:/usr/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-3.4.0/lib64:/usr/local/tools/gcc-3.4.0/lib
clean_environment
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/arm/obj
mkdir -p /scratch/paul/arm/install
mkdir -p /scratch/paul/arm/pkg
mkdir -p /scratch/paul/arm/logs
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf.src.tar.bz2 /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf.backup.tar.bz2
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/make-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/make-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/coreutils-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/coreutils-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' coreutils-5.94
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/binutils-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/binutils-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-2.17
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/gcc-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/gcc-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-4.2
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/expat-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/expat-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' expat-mirror
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/libiconv-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf/libiconv-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' libiconv-1.11
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/csl_docbook-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/csl_docbook-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-trunk
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/getting_started-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/getting_started-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-stable
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/installanywhere-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/installanywhere-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' installanywhere-stable
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/dejagnu_boards-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/dejagnu_boards-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' dejagnu-boards-trunk
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' scripts-trunk
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/xfails-2007q1-10.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/xfails-2007q1-10.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' xfails-trunk
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/src/getting-started-stable/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --with-release-config=4.2-arm-none-symbianelf-lite '--with-components=make coreutils binutils gcc expat libiconv csl_docbook getting_started installanywhere branding contents comparison dejagnu_boards scripts xfails' '--with-host_os-name=IA32 GNU/Linux' --with-target-arch-name=ARM --with-target-os-name=SymbianOS '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/arm/src/csl-docbook-trunk --with-version-string=2007q1-10 '--with-brand=Sourcery G++ Lite' '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --with-license=lite
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/paul/arm/install htmldir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/man docdir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/paul/arm/src/binutils-2.17 /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
touch /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/.gnu-stamp
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q1-10' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/paul/arm/install htmldir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/install
rm -f lib/libiberty.a
rm -f lib/charset.alias
rm -f 'bin/*gccbug'
popd
copy_dir_clean /scratch/paul/arm/src/binutils-2.17/include /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
chmod -R u+w /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/bfd/.libs/libbfd.a /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/bfd/bfd.h /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/paul/arm/src/binutils-2.17/bfd/elf-bfd.h /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/opcodes/.libs/libopcodes.a /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery --enable-languages=c,c++ '--with-versuffix=CodeSourcery Sourcery G++ Lite 2007q1-10' '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q1-10' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories --with-build-time-tools=/scratch/paul/arm/install/arm-none-symbianelf/bin --with-build-time-tools=/scratch/paul/arm/install/arm-none-symbianelf/bin
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make prefix=/scratch/paul/arm/install htmldir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/share/doc/arm-2007q1-10-arm-none-symbianelf/man install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/install
rm -f lib/libiberty.a
rm -f lib/charset.alias
rm -f bin/arm-none-symbianelf-gccbug
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/src/expat-mirror/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushd /scratch/paul/arm/install
rm -f lib/libiberty.a
rm -f lib/charset.alias
rm -f 'bin/*gccbug'
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
find /scratch/paul/arm/install -name '*.la' -exec rm '{}' ';'
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushd /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.2.0/include-fixed
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-addr2line
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-ar
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-as
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-c++
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-c++filt
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-cpp
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-g++
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gcc
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gcc-4.2.0
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gcov
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gprof
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-ld
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-nm
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-objcopy
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-objdump
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-ranlib
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-readelf
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-size
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-strings
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-strip
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/ar
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/as
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/c++
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/g++
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/gcc
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/ld
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/nm
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/objdump
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/ranlib
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/strip
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.2.0/cc1
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.2.0/collect2
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.2.0/install-tools/fixincl
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.2.0/cc1plus
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/arm-none-symbianelf/lib/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/arm-none-symbianelf/lib/mfloat-abi=softfp/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.2.0/libgcc.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.2.0/libgcov.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.2.0/softfp/libgcc.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.2.0/softfp/libgcov.a || true
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
rm -f /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/paul/arm/obj
rm -f arm-2007q1
ln -s /scratch/paul/arm/install arm-2007q1
tar cjf /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2007q1/arm-none-symbianelf arm-2007q1/bin arm-2007q1/include arm-2007q1/lib arm-2007q1/libexec arm-2007q1/share
rm -f arm-2007q1
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
/scratch/paul/arm/scripts/gnu-rpm-inst -i /scratch/paul/arm/install -l /scratch/paul/arm/logs -o /scratch/paul/arm/obj -p /scratch/paul/arm/pkg -s /scratch/paul/arm/src -T /scratch/paul/arm/testlogs -h i686-pc-linux-gnu 4.2-arm-none-symbianelf-lite.cfg
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
/scratch/paul/arm/scripts/gnu-installanywhere -i /scratch/paul/arm/install -l /scratch/paul/arm/logs -o /scratch/paul/arm/obj -p /scratch/paul/arm/pkg -s /scratch/paul/arm/src -T /scratch/paul/arm/testlogs -h i686-pc-linux-gnu -f /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu/license.html 4.2-arm-none-symbianelf-lite.cfg
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32
ln -s . arm-2007q1
tar xf /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm arm-2007q1
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/getting-started-stable/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --with-release-config=4.2-arm-none-symbianelf-lite '--with-components=make coreutils binutils gcc expat libiconv csl_docbook getting_started installanywhere branding contents comparison dejagnu_boards scripts xfails' '--with-host_os-name=IA32 Windows' --with-target-arch-name=ARM --with-target-os-name=SymbianOS '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/arm/src/csl-docbook-trunk --with-version-string=2007q1-10 '--with-brand=Sourcery G++ Lite' '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --with-license=lite
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/man docdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/libiconv-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/libiconv-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/libiconv-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/libiconv-1.11/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2007q1-10-arm-none-symbianelf-i686-mingw32/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/libiconv-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j1
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/libiconv-2007q1-10-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/make-src-2007q1-10-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/arm/src/make-3.81 /scratch/paul/arm/obj/make-src-2007q1-10-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/arm/obj/make-src-2007q1-10-arm-none-symbianelf-i686-mingw32
touch /scratch/paul/arm/obj/make-src-2007q1-10-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/make-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/make-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/make-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/obj/make-src-2007q1-10-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --program-prefix=cs-
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/make-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/make-2007q1-10-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/coreutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/arm/src/coreutils-5.94 /scratch/paul/arm/obj/coreutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/arm/obj/coreutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32
touch /scratch/paul/arm/obj/coreutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/coreutils-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/coreutils-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/coreutils-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/obj/coreutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --program-prefix=cs-
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/coreutils-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/coreutils-2007q1-10-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/arm/src/binutils-2.17 /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32
touch /scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/obj/binutils-src-2007q1-10-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q1-10' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f lib/charset.alias
rm -f 'bin/*gccbug'
popd
copy_dir_clean /scratch/paul/arm/src/binutils-2.17/include /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/include
chmod -R u+w /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/include
mkdir -p /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/libiberty/libiberty.a /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/bfd/.libs/libbfd.a /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/bfd/bfd.h /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/paul/arm/src/binutils-2.17/bfd/elf-bfd.h /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/paul/arm/obj/binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/opcodes/.libs/libopcodes.a /scratch/paul/arm/obj/host-binutils-2007q1-10-arm-none-symbianelf-i686-mingw32/usr/lib
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery --enable-languages=c,c++ '--with-versuffix=CodeSourcery Sourcery G++ Lite 2007q1-10' '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q1-10' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --with-libiconv-prefix=/scratch/paul/arm/obj/host-libs-2007q1-10-arm-none-symbianelf-i686-mingw32/usr --enable-poison-system-directories --with-build-time-tools=/scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin --with-build-time-tools=/scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j4 all-gcc
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2007q1-10-arm-none-symbianelf-i686-mingw32
make prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2007q1-10-arm-none-symbianelf/man install-gcc
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f lib/charset.alias
rm -f bin/arm-none-symbianelf-gccbug
popd
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/lib/gcc/arm-none-symbianelf /scratch/paul/arm/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/lib /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/lib
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/include/c++ /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/include/c++
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/expat-mirror/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2007q1-10-arm-none-symbianelf-i686-mingw32/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2007q1-10-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/paul/arm/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f lib/charset.alias
rm -f 'bin/*gccbug'
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
find /scratch/paul/arm/install/host-i686-mingw32 -name '*.la' -exec rm '{}' ';'
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/paul/arm/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf/4.2.0/include-fixed
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-addr2line.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-ar.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-as.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-c++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-c++filt.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-cpp.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-g++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc-4.2.0.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gcov.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gprof.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-ld.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-nm.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-objcopy.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-objdump.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-ranlib.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-readelf.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-size.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-strings.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-strip.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/cs-make.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/cs-rm.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/ar.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/as.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/c++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/g++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/gcc.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/ld.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/nm.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/objdump.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/ranlib.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/strip.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.0/cc1.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.0/collect2.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.0/install-tools/fixincl.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.0/cc1plus.exe
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
rm -f /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf-i686-mingw32.tar.bz2
pushd /scratch/paul/arm/install/host-i686-mingw32
popd
pushd /scratch/paul/arm/obj
rm -f arm-2007q1
ln -s /scratch/paul/arm/install/host-i686-mingw32 arm-2007q1
tar cjf /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf-i686-mingw32.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2007q1/arm-none-symbianelf arm-2007q1/bin arm-2007q1/include arm-2007q1/lib arm-2007q1/libexec arm-2007q1/share
rm -f arm-2007q1
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2007q1-10-arm-none-symbianelf-i686-mingw32/bin
/scratch/paul/arm/scripts/gnu-installanywhere -i /scratch/paul/arm/install/host-i686-mingw32 -l /scratch/paul/arm/logs -o /scratch/paul/arm/obj -p /scratch/paul/arm/pkg -s /scratch/paul/arm/src -T /scratch/paul/arm/testlogs -h i686-mingw32 -f /scratch/paul/arm/obj/getting_started-2007q1-10-arm-none-symbianelf-i686-mingw32/license.html 4.2-arm-none-symbianelf-lite.cfg
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
cat > /scratch/paul/arm/obj/gnu-2007q1-10.txt <<'EOF0'
Version Information
===================

Version:           2007q1-10
Host(s):           i686-pc-linux-gnu i686-mingw32
Target:            arm-none-symbianelf

Build Information
=================

Build date:             20070502
Build machine:          elphaba.codesourcery.com
Build operating system: Red Hat Enterprise Linux ES release 4 (Nahant Update 4)
Build uname:            Linux elphaba.codesourcery.com 2.6.9-42.0.10.ELsmp #1 SMP Fri Feb 16 17:13:42 EST 2007 x86_64 unknown unknown GNU/Linux
Build user:             paul

EOF0
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup
rm -rf /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts
mkdir /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-release /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-release
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-common /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-common
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-package /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test-package
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-summary /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test-summary
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-logconv-xfail /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-logconv-xfail
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-qemu /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-qemu
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-rpm-inst /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-rpm-inst
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/build-rpm-installer /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/build-rpm-installer
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/4.2-arm-none-symbianelf-lite.cfg /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/4.2-arm-none-symbianelf-lite.cfg
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/4.2-arm-lite.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/4.2-arm-lite.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/4.2-lite.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/4.2-lite.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/4.2-sourceryg++.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/4.2-sourceryg++.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/common.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/common.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/eclipse.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/eclipse.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/docs.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/docs.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/common-lite.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/common-lite.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/4.2-arm.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/4.2-arm.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/arm/scripts/release-configs/4.2-arm-none-symbianelf.inc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/release-configs/4.2-arm-none-symbianelf.inc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/make /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/make
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/coreutils /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/coreutils
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/binutils /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/binutils
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/gcc /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/gcc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/expat /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/expat
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/libiconv /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/libiconv
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/csl_docbook /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/csl_docbook
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/getting_started /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/getting_started
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/installanywhere /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/installanywhere
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/branding /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/branding
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/contents /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/contents
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/comparison /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/comparison
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/dejagnu_boards /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/dejagnu_boards
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/scripts /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/scripts
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/xfails /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/modules/xfails
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-installanywhere /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-installanywhere
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-ia-helper /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-ia-helper
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-ia-helper-mm /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-ia-helper-mm
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-ia-helper-unpack /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-ia-helper-unpack
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-ia-helper-munpack /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-ia-helper-munpack
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iap-sourcerygxx /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iap-sourcerygxx
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iamm-eclipse /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iamm-eclipse
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iamm-common /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iamm-common
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iamm-jvm /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iamm-jvm
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iauuid /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iauuid
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iastring /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iastring
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iaversion /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/iaversion
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/libia-common /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/libia-common
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/libia-mm /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/libia-mm
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/libia /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/libia
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-branding /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test-branding
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-contents /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test-contents
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-comparison /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test-comparison
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-comparison-helper /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/gnu-test-comparison-helper
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/objcompare.c /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf.backup/scripts/objcompare.c
pushd /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf
tar cjf /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf.backup.tar.bz2 --owner=0 --group=0 arm-2007q1-10-arm-none-symbianelf.backup
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
cp /scratch/paul/arm/obj/gnu-2007q1-10.txt /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
cp /scratch/paul/arm/logs/arm-2007q1-10-arm-none-symbianelf.sh /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf/arm-2007q1-10-arm-none-symbianelf
pushd /scratch/paul/arm/obj/pkg-2007q1-10-arm-none-symbianelf
tar cjf /scratch/paul/arm/pkg/arm-2007q1-10-arm-none-symbianelf.src.tar.bz2 --owner=0 --group=0 arm-2007q1-10-arm-none-symbianelf
popd
